# django-dto-cattrs

Like [django-dto](https://github.com/nicogall/django-dto) but dataclass features not coupled to the Python version in use.

Uses [attrs](https://github.com/python-attrs/attrs) and [cattrs](https://github.com/python-attrs/cattrs) under the hood.
